==> passport-azure-ad-1.4.6.tgz: package/test/Nodeunit_test/validator_test.js <==
/**
 * Copyright (c) Microsoft Corporation
 *  All Rights Reserved
 *  MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify,
 * merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
 * OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
'use strict';

const Validator = require('../../lib/passport-azure-ad/validator').Validator;

/*
 ======== A Handy Little Nodeunit Reference ========
 https://github.com/caolan/nodeunit

 Test methods:
 test.expect(numAssertions)
 test.done()
 Test assertions:
 test.ok(value, [message])
 test.equal(actual, expected, [message])
 test.notEqual(actual, expected, [message])
 test.deepEqual(actual, expected, [message])
 test.notDeepEqual(actual, expected, [message])
 test.strictEqual(actual, expected, [message])
 test.notStrictEqual(actual, expected, [message])
 test.throws(block, [error], [message])
 test.doesNotThrow(block, [error], [message])
 test.ifError(value)
 */

const checker = new Validator({ something: Validator.isNonEmpty });

exports.validator = {

  'has option': (test) => {
    test.expect(1);
    // tests here

    test.doesNotThrow(
      () => {
        checker.validate({ something: 'test' });
      },
      Error,
      'Should not fail with option present'
    );

    test.done();
  },
  'missing option': (test) => {
    test.expect(1);
    // tests here

    test.throws(
      () => {
        checker.validate({ bar: 'test' });
      },
      Error,
      'Should  fail with option missing'
    );

    test.done();
  },
  'no options': (test) => {
    test.expect(1);
    // tests here

    test.doesNotThrow(
      () => {
        const myChecker = new Validator({});
        myChecker.validate({});
      },
      Error,
      'Should not fail with no options or config'
    );

    test.done();
  },
};

==> passport-azure-ad-3.0.8.tgz: package/test/Nodeunit_test/validator_test.js <==
/**
 * Copyright (c) Microsoft Corporation
 *  All Rights Reserved
 *  MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify,
 * merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
 * OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
'use strict';

const Validator = require('../../lib/validator').Validator;

/*
 ======== A Handy Little Nodeunit Reference ========
 https://github.com/caolan/nodeunit

 Test methods:
 test.expect(numAssertions)
 test.done()
 Test assertions:
 test.ok(value, [message])
 test.equal(actual, expected, [message])
 test.notEqual(actual, expected, [message])
 test.deepEqual(actual, expected, [message])
 test.notDeepEqual(actual, expected, [message])
 test.strictEqual(actual, expected, [message])
 test.notStrictEqual(actual, expected, [message])
 test.throws(block, [error], [message])
 test.doesNotThrow(block, [error], [message])
 test.ifError(value)
 */

const checker = new Validator({ something: Validator.isNonEmpty });

exports.validator = {

  'has option': (test) => {
    test.expect(1);
    // tests here

    test.doesNotThrow(
      () => {
        checker.validate({ something: 'test' });
      },
      Error,
      'Should not fail with option present'
    );

    test.done();
  },
  'missing option': (test) => {
    test.expect(1);
    // tests here

    test.throws(
      () => {
        checker.validate({ bar: 'test' });
      },
      Error,
      'Should  fail with option missing'
    );

    test.done();
  },
  'no options': (test) => {
    test.expect(1);
    // tests here

    test.doesNotThrow(
      () => {
        const myChecker = new Validator({});
        myChecker.validate({});
      },
      Error,
      'Should not fail with no options or config'
    );

    test.done();
  },
};
